==> nomachine-8.4.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXTwoFactorLoginDB.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXTwoFactorLoginDB::BEGIN{package NXTwoFactorLoginDB;no warnings;require 
Error;do{"\x45\x72\x72\x6f\x72"->import ("\x3a\x74\x72\x79")};}sub 
NXTwoFactorLoginDB::savePublicKey{package NXTwoFactorLoginDB;no warnings;(my $user
=main::urlencode (shift (@_)));(my $key=main::urlencode (shift (@_)));if (($user
 eq (""))){Logger::warning (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x55\x73\x65\x72\x6e\x61\x6d\x65\x20\x69\x73\x20\x65\x6d\x70\x74\x79\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x73\x61\x76\x65\x20\x74\x68\x65\x20\x70\x75\x62\x6c\x69\x63\x20\x6b\x65\x79\x2e"
);return ((0x0ed2+ 185-0x0f8b));}if (($key eq (""))){Logger::warning (((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x73\x61\x76\x65\x20\x65\x6d\x70\x74\x79\x20\x70\x75\x62\x6c\x69\x63\x20\x6b\x65\x79\x20\x66\x6f\x72\x20\x75\x73\x65\x72\x20\x27"
.$user)."\x27\x2e"));return ((0x0254+ 2614-0x0c8a));}__lock ();(my $file=
NXPaths::getTwoFactorPublicKeys ());(my $openMode=(($NXBits::O_CREAT+
$NXBits::O_WRONLY)+$NXBits::O_APPEND));(my $FD=main::nxopen ($file,$openMode,
$NXBits::UserReadWrite));if ((not (defined ($FD)))){(my $error=
libnxh::NXGetError ());(my $errorName=libnxh::NXGetErrorName ());(my $errorString
=libnxh::NXGetErrorString ());if ((not (defined ($FD)))){Logger::warning ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x70\x75\x62\x6c\x69\x63\x20\x6b\x65\x79\x20\x74\x6f\x20\x74\x68\x65\x20\x66\x69\x6c\x65\x20\x27"
.$file)."\x27\x2e").(((("\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".
$errorString)."\x27\x2c\x20").$error)."\x2e")));__unlock ();return (
(0x0c03+ 1147-0x107e));}}(my $data=((($user."\x20").$key)."\x0a"));if ((
main::nxwrite ($FD,$data)==(-(0x16d1+ 3327-0x23cf)))){(my $error=
libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
main::nxclose ($FD);Logger::warning ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x70\x75\x62\x6c\x69\x63\x20\x6b\x65\x79\x20\x74\x6f\x20\x74\x68\x65\x20\x66\x69\x6c\x65\x20\x27"
.$file)."\x27\x2e").(((("\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".
$errorString)."\x27\x2c\x20").$error)."\x2e")));__unlock ();return (
(0x0578+ 2862-0x10a6));}main::nxclose ($FD);__unlock ();return (
(0x13bb+ 3887-0x22e9));}sub NXTwoFactorLoginDB::getPublicKeys{package 
NXTwoFactorLoginDB;no warnings;(my $user=shift (@_));(my (@keys)=
getAllPublicKeys ());(my (@userKeys)=());for ((my $i=(0x0c32+ 2824-0x173a));($i<
@keys);($i=($i+(0x079a+ 3961-0x1711)))){if (($user eq @keys[$i])){push (
@userKeys,$keys[$i+(0x03f7+ 8390-0x24bc)]);}}return (@userKeys);}sub 
NXTwoFactorLoginDB::getAllPublicKeys{package NXTwoFactorLoginDB;no warnings;(my $file
=NXPaths::getTwoFactorPublicKeys ());unless (Common::NXFile::isExists ($file)){
Logger::debug (((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x3a\x20\x46\x69\x6c\x65\x20\x27"
.$file)."\x27\x20\x64\x6f\x65\x73\x20\x6e\x6f\x74\x20\x65\x78\x69\x73\x74\x2e"))
;return (());}__lockShared ();(my $fileHandle=main::nxopen ($file,
$NXBits::O_RDONLY));unless (defined ($fileHandle)){(my $errorNumber=
libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
Logger::debug ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x27"
.$file)."\x27\x20\x66\x6f\x72\x20\x72\x65\x61\x64\x2e").((((
"\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".$errorString)."\x27\x2c\x20").
$errorNumber)."\x2e")));__unlock ();return (());}(my (@content)=());while (
main::nxreadLine ($fileHandle,(\$_))){chomp ($_);(my ($user,$key)=split ( / / ,
$_,(0x1bd7+ 637-0x1e51)));($user=main::urldecode ($user));($key=main::urldecode 
($key));Logger::debug3 (((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x55\x73\x65\x72\x20\x27"
.$user)."\x27\x20\x6b\x65\x79\x20\x27").$key)."\x27\x2e"));push (@content,$user,
$key);}main::nxclose ($fileHandle);__unlock ();return (@content);}sub 
NXTwoFactorLoginDB::removeUserKeys{package NXTwoFactorLoginDB;no warnings;(my $username
=shift (@_));(my $file=NXPaths::getTwoFactorPublicKeys ());(my $tempFile=(($file
."\x2e\x74\x6d\x70\x2e").$ $));
 unless (Common::NXFile::isExists ($file)){
Logger::warning (((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x46\x69\x6c\x65\x20\x27"
.$file)."\x27\x20\x64\x6f\x65\x73\x20\x6e\x6f\x74\x20\x65\x78\x69\x73\x74\x2e"))
;return ((0x0f63+ 394-0x10ed));}__lock ();(my $FD=main::nxopen ($file,
$NXBits::O_RDONLY));unless (defined ($FD)){(my $errorNumber=libnxh::NXGetError 
());(my $errorString=libnxh::NXGetErrorString ());Logger::warning ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x27"
.$file)."\x27\x20\x66\x6f\x72\x20\x72\x65\x61\x64\x2e").((((
"\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".$errorString)."\x27\x2c\x20").
$errorNumber)."\x2e")));__unlock ();return ((0x1120+ 3764-0x1fd4));}if (
Common::NXFile::isExists ($tempFile)){unlink ($tempFile);}(my $openMode=((
$NXBits::O_CREAT+$NXBits::O_WRONLY)+$NXBits::O_APPEND));(my $tempFD=main::nxopen
 ($tempFile,$openMode,$NXBits::UserReadWrite));unless (defined ($tempFD)){(my $errorNumber
=libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
Logger::warning ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x27"
.$tempFile)."\x27\x20\x66\x6f\x72\x20\x77\x72\x69\x74\x65\x2e").((((
"\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".$errorString)."\x27\x2c\x20").
$errorNumber)."\x2e")));__unlock ();return ((0x02f0+ 7945-0x21f9));}&try (sub{
while (main::nxreadLine ($FD,(\$_))){(my $line=$_);chomp ($line);(my ($keyUser,
$key)=split ( / / ,$line,(0x021f+ 2314-0x0b26)));($keyUser=main::urldecode (
$keyUser));if (($keyUser eq $username)){($flag_del=(0x0141+ 9447-0x2627));}else{
Common::NXCore::nxwriteOrThrowException ($tempFD,$_);}}},&otherwise (sub{(my $error
=shift (@_));main::nxclose ($tempFD);main::nxclose ($FD);__unlock ();
Logger::error (((
"\x55\x6e\x65\x78\x70\x65\x63\x65\x64\x20\x65\x72\x72\x6f\x72\x20\x77\x68\x69\x6c\x65\x20\x72\x65\x6d\x6f\x76\x69\x6e\x67\x20\x73\x61\x76\x65\x64\x20\x75\x73\x65\x72\x20\x74\x77\x6f\x20\x66\x61\x63\x74\x6f\x72\x20\x6b\x65\x79\x2e\x20"
.$error)."\x2e"));return ((0x00c5+ 5762-0x1747));}));main::nxclose ($tempFD);
main::nxclose ($FD);if ((not (rename ($tempFile,$file)))){__unlock ();
Logger::error ((((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6e\x61\x6d\x65\x20\x66\x69\x6c\x65\x20\x27"
.$tempFile)."\x27\x20\x74\x6f\x20\x27").$file)."\x27\x2e\x20").$!));return (
(0x0d04+ 5105-0x20f5));}(my ($errorName),$errorCode);if ((
Common::NXFile::setOwnerShipAndPermissionsForNX ($file,(\$errorName),(
\$errorCode))==(-(0x069d+ 130-0x071e)))){__unlock ();Logger::error ((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x73\x65\x74\x20\x6f\x77\x6e\x65\x72\x73\x68\x69\x70\x20\x27\x6e\x78\x27\x20\x6f\x6e\x20\x66\x69\x6c\x65\x20\x27"
.$file)."\x27\x20\x66\x6f\x72\x20\x75\x73\x65\x72\x20\x6e\x78\x2e\x20").
$errorName));return ((0x01b7+ 8008-0x20ff));}__unlock ();return ($flag_del);}
package NXTwoFactorLoginDB;no warnings;my ($lockFD);sub __lock{(my $lockMode=(
shift (@_)||$NXBits::LOCK_EX));(my $lockFile=(NXPaths::getTwoFactorPublicKeys ()
."\x2e\x6c\x6f\x63\x6b"));(my $openMode=(($NXBits::O_CREAT+$NXBits::O_WRONLY)+
$NXBits::O_APPEND));($lockFD=main::nxopen ($lockFile,$openMode,
$NXBits::UserReadWrite));if ((not (defined ($lockFD)))){(my $error=
libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
Logger::warning ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x66\x69\x6c\x65\x20\x27"
.$lockFile)."\x27\x2e").(((("\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".
$errorString)."\x27\x2c\x20").$error)."\x2e")));return ((0x03ba+ 876-0x0726));}
main::nxflock ($lockFD,$lockMode);}sub __lockShared{return (__lock (
$NXBits::LOCK_SH));}sub __unlock{if (defined ($lockFD)){main::nxclose ($lockFD);
}($lockFD=undef);}return ((0x1e13+ 2220-0x26be));

==> nomachine-8.6.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXTwoFactorLoginDB.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXTwoFactorLoginDB::BEGIN{package NXTwoFactorLoginDB;no warnings;require 
Error;do{"\x45\x72\x72\x6f\x72"->import ("\x3a\x74\x72\x79")};}sub 
NXTwoFactorLoginDB::savePublicKey{package NXTwoFactorLoginDB;no warnings;(my $user
=main::urlencode (shift (@_)));(my $key=main::urlencode (shift (@_)));if (($user
 eq (""))){Logger::warning (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x55\x73\x65\x72\x6e\x61\x6d\x65\x20\x69\x73\x20\x65\x6d\x70\x74\x79\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x73\x61\x76\x65\x20\x74\x68\x65\x20\x70\x75\x62\x6c\x69\x63\x20\x6b\x65\x79\x2e"
);return ((0x1ee7+ 1627-0x2542));}if (($key eq (""))){Logger::warning (((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x73\x61\x76\x65\x20\x65\x6d\x70\x74\x79\x20\x70\x75\x62\x6c\x69\x63\x20\x6b\x65\x79\x20\x66\x6f\x72\x20\x75\x73\x65\x72\x20\x27"
.$user)."\x27\x2e"));return ((0x03d6+ 4878-0x16e4));}__lock ();(my $file=
NXPaths::getTwoFactorPublicKeys ());(my $openMode=(($NXBits::O_CREAT+
$NXBits::O_WRONLY)+$NXBits::O_APPEND));(my $FD=main::nxopen ($file,$openMode,
$NXBits::UserReadWrite));if ((not (defined ($FD)))){(my $error=
libnxh::NXGetError ());(my $errorName=libnxh::NXGetErrorName ());(my $errorString
=libnxh::NXGetErrorString ());if ((not (defined ($FD)))){Logger::warning ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x70\x75\x62\x6c\x69\x63\x20\x6b\x65\x79\x20\x74\x6f\x20\x74\x68\x65\x20\x66\x69\x6c\x65\x20\x27"
.$file)."\x27\x2e").(((("\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".
$errorString)."\x27\x2c\x20").$error)."\x2e")));__unlock ();return (
(0x02b2+ 2462-0x0c50));}}(my $data=((($user."\x20").$key)."\x0a"));if ((
main::nxwrite ($FD,$data)==(-(0x1e6b+ 123-0x1ee5)))){(my $error=
libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
main::nxclose ($FD);Logger::warning ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x70\x75\x62\x6c\x69\x63\x20\x6b\x65\x79\x20\x74\x6f\x20\x74\x68\x65\x20\x66\x69\x6c\x65\x20\x27"
.$file)."\x27\x2e").(((("\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".
$errorString)."\x27\x2c\x20").$error)."\x2e")));__unlock ();return (
(0x0871+ 6123-0x205c));}main::nxclose ($FD);__unlock ();return (
(0x0203+ 4260-0x12a6));}sub NXTwoFactorLoginDB::getPublicKeys{package 
NXTwoFactorLoginDB;no warnings;(my $user=shift (@_));(my (@keys)=
getAllPublicKeys ());(my (@userKeys)=());for ((my $i=(0x04d5+ 1579-0x0b00));($i<
@keys);($i=($i+(0x04d7+ 381-0x0652)))){if (($user eq @keys[$i])){push (@userKeys
,$keys[$i+(0x006d+ 5523-0x15ff)]);}}return (@userKeys);}sub 
NXTwoFactorLoginDB::getAllPublicKeys{package NXTwoFactorLoginDB;no warnings;(my $file
=NXPaths::getTwoFactorPublicKeys ());unless (Common::NXFile::isExists ($file)){
Logger::debug (((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x3a\x20\x46\x69\x6c\x65\x20\x27"
.$file)."\x27\x20\x64\x6f\x65\x73\x20\x6e\x6f\x74\x20\x65\x78\x69\x73\x74\x2e"))
;return (());}__lockShared ();(my $fileHandle=main::nxopen ($file,
$NXBits::O_RDONLY));unless (defined ($fileHandle)){(my $errorNumber=
libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
Logger::debug ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x27"
.$file)."\x27\x20\x66\x6f\x72\x20\x72\x65\x61\x64\x2e").((((
"\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".$errorString)."\x27\x2c\x20").
$errorNumber)."\x2e")));__unlock ();return (());}(my (@content)=());while (
main::nxreadLine ($fileHandle,(\$_))){chomp ($_);(my ($user,$key)=split ( / / ,
$_,(0x05d4+ 1817-0x0cea)));($user=main::urldecode ($user));($key=main::urldecode
 ($key));Logger::debug3 (((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x55\x73\x65\x72\x20\x27"
.$user)."\x27\x20\x6b\x65\x79\x20\x27").$key)."\x27\x2e"));push (@content,$user,
$key);}main::nxclose ($fileHandle);__unlock ();return (@content);}sub 
NXTwoFactorLoginDB::removeUserKeys{package NXTwoFactorLoginDB;no warnings;(my $username
=shift (@_));(my $file=NXPaths::getTwoFactorPublicKeys ());(my $tempFile=(($file
."\x2e\x74\x6d\x70\x2e").$ $));
 unless (Common::NXFile::isExists ($file)){
Logger::warning (((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x46\x69\x6c\x65\x20\x27"
.$file)."\x27\x20\x64\x6f\x65\x73\x20\x6e\x6f\x74\x20\x65\x78\x69\x73\x74\x2e"))
;return ((0x10e6+ 3616-0x1f06));}__lock ();(my $FD=main::nxopen ($file,
$NXBits::O_RDONLY));unless (defined ($FD)){(my $errorNumber=libnxh::NXGetError 
());(my $errorString=libnxh::NXGetErrorString ());Logger::warning ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x27"
.$file)."\x27\x20\x66\x6f\x72\x20\x72\x65\x61\x64\x2e").((((
"\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".$errorString)."\x27\x2c\x20").
$errorNumber)."\x2e")));__unlock ();return ((0x0def+ 2985-0x1998));}if (
Common::NXFile::isExists ($tempFile)){unlink ($tempFile);}(my $openMode=((
$NXBits::O_CREAT+$NXBits::O_WRONLY)+$NXBits::O_APPEND));(my $tempFD=main::nxopen
 ($tempFile,$openMode,$NXBits::UserReadWrite));unless (defined ($tempFD)){(my $errorNumber
=libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
Logger::warning ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x27"
.$tempFile)."\x27\x20\x66\x6f\x72\x20\x77\x72\x69\x74\x65\x2e").((((
"\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".$errorString)."\x27\x2c\x20").
$errorNumber)."\x2e")));__unlock ();return ((0x1fb0+ 1397-0x2525));}&try (sub{
while (main::nxreadLine ($FD,(\$_))){(my $line=$_);chomp ($line);(my ($keyUser,
$key)=split ( / / ,$line,(0x0da9+ 5832-0x246e)));($keyUser=main::urldecode (
$keyUser));if (($keyUser eq $username)){($flag_del=(0x05d6+ 3780-0x1499));}else{
Common::NXCore::nxwriteOrThrowException ($tempFD,$_);}}},&otherwise (sub{(my $error
=shift (@_));main::nxclose ($tempFD);main::nxclose ($FD);__unlock ();
Logger::error (((
"\x55\x6e\x65\x78\x70\x65\x63\x65\x64\x20\x65\x72\x72\x6f\x72\x20\x77\x68\x69\x6c\x65\x20\x72\x65\x6d\x6f\x76\x69\x6e\x67\x20\x73\x61\x76\x65\x64\x20\x75\x73\x65\x72\x20\x74\x77\x6f\x20\x66\x61\x63\x74\x6f\x72\x20\x6b\x65\x79\x2e\x20"
.$error)."\x2e"));return ((0x00dc+ 8698-0x22d6));}));main::nxclose ($tempFD);
main::nxclose ($FD);if ((not (rename ($tempFile,$file)))){__unlock ();
Logger::error ((((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6e\x61\x6d\x65\x20\x66\x69\x6c\x65\x20\x27"
.$tempFile)."\x27\x20\x74\x6f\x20\x27").$file)."\x27\x2e\x20").$!));return (
(0x0183+ 3611-0x0f9e));}(my ($errorName),$errorCode);if ((
Common::NXFile::setOwnerShipAndPermissionsForNX ($file,(\$errorName),(
\$errorCode))==(-(0x0afd+ 3027-0x16cf)))){__unlock ();Logger::error ((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x73\x65\x74\x20\x6f\x77\x6e\x65\x72\x73\x68\x69\x70\x20\x27\x6e\x78\x27\x20\x6f\x6e\x20\x66\x69\x6c\x65\x20\x27"
.$file)."\x27\x20\x66\x6f\x72\x20\x75\x73\x65\x72\x20\x6e\x78\x2e\x20").
$errorName));return ((0x08c6+ 954-0x0c80));}__unlock ();return ($flag_del);}
package NXTwoFactorLoginDB;no warnings;my ($lockFD);sub __lock{(my $lockMode=(
shift (@_)||$NXBits::LOCK_EX));(my $lockFile=(NXPaths::getTwoFactorPublicKeys ()
."\x2e\x6c\x6f\x63\x6b"));(my $openMode=(($NXBits::O_CREAT+$NXBits::O_WRONLY)+
$NXBits::O_APPEND));($lockFD=main::nxopen ($lockFile,$openMode,
$NXBits::UserReadWrite));if ((not (defined ($lockFD)))){(my $error=
libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
Logger::warning ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x66\x69\x6c\x65\x20\x27"
.$lockFile)."\x27\x2e").(((("\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".
$errorString)."\x27\x2c\x20").$error)."\x2e")));return ((0x001c+ 1429-0x05b1));}
main::nxflock ($lockFD,$lockMode);}sub __lockShared{return (__lock (
$NXBits::LOCK_SH));}sub __unlock{if (defined ($lockFD)){main::nxclose ($lockFD);
}($lockFD=undef);}return ((0x0e3a+ 2151-0x16a0));
